==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/BitmapExport/ts/BitmapExport_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+88"/>
        <source>Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/BitmapExport/ts/BitmapExport_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+105"/>
        <source>Files</source>
        <translation>Bestanden</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>Exporteren als bitmap</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>Fout bij het genereren van het bitmap bestand &quot;%1&quot;:%2</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>Bitmap bestand is aangemaakt als &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>Bitmap export</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Breedte:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>Hoogte:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>Pixels per tekening eenheid:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>Rand:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation>Achtergrond</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>Wit</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>Zwart</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>Bit&amp;map export...</translation>
    </message>
</context>
</TS>
